@@ -186,7 +186,7 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
                         buf[nr] = 0;
                         String mimestr = MimeType::findByContent (buf, nr);
                         if (mimestr.startsWith (String ("text/")) &&
-                                strncmp (buf, "RIFF", 4))
+                                !strncmp (buf, "RIFF", 4))
                             maybe_playlist = false;
                     }
                 }
