@@ -422,6 +422,7 @@ static void create_menu (Application * app) {
     app->menu_item_playlist_paste = gtk_menu_item_new_with_label("Paste");
     app->menu_item_playlist_paste_in_group = gtk_menu_item_new_with_label ("Paste in new Group");
     app->menu_item_playlist_cut = gtk_menu_item_new_with_label("Cut");
+    app->menu_item_playlist_title = gtk_menu_item_new_with_label("Change Title");
     app->menu_item_playlist_showall = gtk_check_menu_item_new_with_label ("Show All");
     app->menu_item_playlist_edit = gtk_check_menu_item_new_with_label ("Edit");
     item_close = gtk_menu_item_new_with_label ("Close");
@@ -446,6 +447,7 @@ static void create_menu (Application * app) {
     gtk_menu_append (menu_playlist, app->menu_item_playlist_paste_in_group);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_cut);
     gtk_menu_append (menu_playlist, gtk_separator_menu_item_new ());
+    gtk_menu_append (menu_playlist, app->menu_item_playlist_title);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_showall);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_edit);
     gtk_menu_append (menu_players, app->menu_item_media_server);
@@ -480,6 +482,8 @@ static void create_menu (Application * app) {
         GTK_SIGNAL_FUNC (cb_playlistPasteInNewGroup), app);
     g_signal_connect (G_OBJECT (app->menu_item_playlist_cut), "activate",
         GTK_SIGNAL_FUNC (cb_playlistCut), app);
+    g_signal_connect (G_OBJECT (app->menu_item_playlist_title), "activate",
+        GTK_SIGNAL_FUNC (cb_playlistTitle), app);
     g_signal_connect (G_OBJECT (item_playlist_show), "toggled",
         GTK_SIGNAL_FUNC (togglePlaylistShow), app);
     g_signal_connect (G_OBJECT (app->menu_item_playlist_showall), "toggled",
