@@ -77,6 +77,7 @@ typedef struct _Application {
     GtkWidget * menu_item_playlist_cut;
     GtkWidget * menu_item_playlist_showall;
     GtkWidget * menu_item_playlist_edit;
+    GtkWidget * menu_item_playlist_title;
     GtkWidget * menu_item_media_server;
     GtkWidget * menu_item_mplayer;
     GtkWidget * menu_item_npp;
@@ -120,6 +121,7 @@ void cb_playlistCopy (GtkButton * button, Application * app);
 void cb_playlistPaste (GtkButton * button, Application * app);
 void cb_playlistPasteInNewGroup (GtkButton * button, Application * app);
 void cb_playlistCut (GtkButton * button, Application * app);
+void cb_playlistTitle (GtkButton * button, Application * app);
 void cb_playlist_prev (GtkButton * button, void *ctr);
 void cb_playlist_play (GtkButton * button, void *ctr);
 void cb_playlist_next (GtkButton * button, void *ctr);
