@@ -114,7 +114,11 @@ KDE_NO_EXPORT void Recent::closed () {
 }
 
 KDE_NO_EXPORT void Recent::activate () {
-    app_open_location ((const char *) src, app);
+    Document *doc = new SourceDocument (CONTROL (app), src);
+    String pos = getAttribute ("clipBegin");
+    if (!pos.isEmpty ())
+        doc->clip_begin = parseTimeString (pos);
+    CONTROL(app)->openDocument (doc, NULL);
 }
 
 KDE_NO_CDTOR_EXPORT
