@@ -52,7 +52,7 @@ public:
     KDE_NO_CDTOR_EXPORT Playlist (NodePtr & d) : Mrl (d, id_node_playlist) {}
     Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
-    bool expose () const { return !pretty_name.isEmpty (); }
+    bool expose () const { return !caption.isEmpty (); }
     void closed ();
 };
 
