@@ -476,7 +476,7 @@ bool Control::setProcess (const char *pname) {
     gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu), true);
     if (old_process)
         old_process->quit ();
-    VIEWAREA(m_app)->setControlsOverlap (m_process != mplayer || use_xvideo);
+    setUseXVideo (use_xvideo);
 }
 
 bool Control::setProcess (Mrl *mrl) {
@@ -870,8 +870,8 @@ void Control::setAspect (float aspect) {
 void Control::setUseXVideo (bool b) {
     mplayer->setUseXv (b);
     use_xvideo = b;
-    if (m_process == mplayer)
-        VIEWAREA(m_app)->setControlsOverlap (b);
+    VIEWAREA(m_app)->setControlsOverlap (b || m_process != mplayer);
+    VIEWAREA(m_app)->enableVideoInputFilter (b && m_process == mplayer);
 }
 
 void cb_view_area_configure (GtkWidget *widget, GdkEventConfigure *event, Application * app) {
