@@ -580,6 +580,7 @@ Mrl::Mrl (NodePtr & d, short id)
     : Element (d, id), cached_ismrl_version (~0),
       media_info (NULL),
       aspect (0), repeat (0),
+      clip_begin (0),
       view_mode (SingleMode),
       resolved (false), bookmarkable (true),
       audio_only (false) {}
@@ -721,6 +722,22 @@ void Mrl::deactivate () {
     Node::deactivate ();
 }
 
+unsigned int Mrl::parseTimeString (const String &ts) {
+    String s (ts);
+    int multiply[] = { 1, 60, 60 * 60, 24 * 60 * 60, 0 };
+    int mpos = 0;
+    double d = 0;
+    while (!s.isEmpty () && multiply[mpos]) {
+        int p = s.lastIndexOf (Char (':'));
+        String t = p >= 0 ? s.mid (p + 1) : s;
+        d += multiply[mpos++] * t.toDouble();
+        s = p >= 0 ? s.left (p) : String ();
+    }
+    if (d > 0.1)
+        return (unsigned int) (d * 10);
+    return 0;
+}
+
 //----------------------%<-----------------------------------------------------
 
 void Mrl::parseParam (const TrieString & para, const String & val) {
