@@ -540,6 +540,8 @@ public:
     virtual void deactivate ();
     virtual void *message (MessageType msg, void *content=NULL);
 
+    static unsigned int parseTimeString (const String &s);
+
     /**
      * If this Mrl is top node of external document, opener has the
      * location in SCR. Typically that's the parent of this node.
@@ -552,6 +554,7 @@ public:
     Single height;
     float aspect;
     int repeat;
+    unsigned int clip_begin;
     unsigned char view_mode;
     bool resolved;
     bool bookmarkable;
