@@ -476,6 +476,14 @@ gboolean cb_treeViewClicked (GtkWidget *view, GdkEventButton *evt, Application *
     return false;
 }
 
+static void setInfoContent (Application *app, Node *node, bool edit_mode) {
+    app_set_info_content (app, node
+            ? (edit_mode
+                ? node->innerXML ()
+                : node->isPlayable () ? node->innerText () : "")
+            : "", edit_mode);
+}
+
 void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
     if (app->in_tree_update || !selection)
         return;
@@ -498,9 +506,7 @@ void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
             if (!node->isPlayable ()) // lazy playlist/recents loading
                 updateTree (app, pld->id);
         } else {
-            app_set_info_content (app, node
-                    ? (pld->edit_mode ? node->innerXML () : node->innerText ())
-                    : "", pld->edit_mode);
+            setInfoContent (app, node.ptr (), pld->edit_mode);
         }
         CONTROL(app)->setCurrentSelected (node);
         if (mrl && pld->id > 0) //FIXME, hack to become less jumpy when changing trees
@@ -517,9 +523,7 @@ void cb_row_activated (GtkTreeView * tree_view, GtkTreePath *path,
         activateTopNode (tree_view, path, pld, node, app);
     } else {
         if (pld->id == 0 || pld->edit_mode)
-            app_set_info_content (app, node
-                    ? (pld->edit_mode ? node->innerXML () : node->innerText ())
-                    : "", pld->edit_mode);
+            setInfoContent (app, node.ptr (), pld->edit_mode);
         if (!pld->edit_mode && (pld->id == 0 || node->mrl ()))
             jump (node.ptr (), CONTROL(app));
     }
@@ -566,9 +570,7 @@ void KMPlayer::rowSelected (Application *app) {
             }
         }
     } else {
-        app_set_info_content (app, node
-                ? (pld->edit_mode ? node->innerXML () : node->innerText ())
-                : "", pld->edit_mode);
+        setInfoContent (app, node.ptr (), pld->edit_mode);
         if (!pld->edit_mode && (pld->id == 0 || node->mrl ()))
             jump (node.ptr (), CONTROL(app));
     }
@@ -963,9 +965,7 @@ void togglePlaylistEdit (GtkCheckMenuItem *menuitem, Application * app) {
         NodePtr node = pld->current;
         if (!node)
             node = pld->document;
-        app_set_info_content (app, node
-                ? (pld->edit_mode ? node->innerXML () : node->innerText ())
-                : "", pld->edit_mode);
+        setInfoContent (app, node.ptr (), pld->edit_mode);
     }
 }
 
