@@ -68,7 +68,7 @@ static void dbusSend (DBusConnection *conn,
 Process::Process (ProcessNotify * ctrl, const char * n, bool xv)
  : m_notify (ctrl), m_viewer (0L), m_name (n),
       m_state (NotRunning), m_old_state (NotRunning),// m_process (0L),
-      start_timer (0), no_video (false), has_xv (xv)
+      start_timer (0), no_video (false), has_xv (xv), is_local_file (false)
       {}
 
 Process::~Process () {
@@ -186,8 +186,10 @@ KMPLAYER_NO_EXPORT bool Process::play (NodePtr _mrl) {
     m_url = m ? m->absolutePath () : String ();
     no_video = m ? m->audio_only : false;
     m_position = m_length = 0;
+    m_user_stop_position = 0;
     m_width = m_height = 0;
     m_aspect = 0.0;
+    is_local_file = false;
     return false;
 }
 
@@ -206,6 +208,11 @@ KMPLAYER_NO_EXPORT void Process::infoMessage (const String &msg) {
         m_mrl->document ()->message (MsgInfoString, (void *) &msg);
 }
 
+void Process::setUserStop () {
+    if (m_state > Buffering && m_length > 0 && is_local_file)
+        m_user_stop_position = m_position;
+}
+
 //-----------------------------------------------------------------------------
 
 static void setupMPlayerFunc (gpointer data) {
@@ -254,7 +261,8 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
     request_seek = NO_SEEK;
     String wd ("/home/user");
     URL url (m_url);
-    if (url.isLocalFile ()) {
+    is_local_file = url.isLocalFile ();
+    if (is_local_file) {
         m_url = url.path ();
         wd = url.path ();
         int pos = wd.lastIndexOf (String ("/"));
@@ -282,21 +290,32 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
     Mrl *mrl = this->mrl ();
     if (mrl->repeat > 0)
         cmdline += String (" -loop ") + String::number (mrl->repeat+1);
+    if (is_local_file && mrl->clip_begin > 10)
+        cmdline += String (" -ss ") + String::number (mrl->clip_begin/10);
     cmdline += Char (' ');
 
     for (NodePtr n = mrl; n; n = n->parentNode ()) {
         if (n->id != id_node_group_node && n->id != id_node_playlist_item)
             break;
-        String plops = convertNode <Element> (n)->getAttribute ("mplayeropts");
-        if (!plops.isNull ()) {
-            gchar ** list = g_strsplit ((const char *) plops, " ", -1);
-            for (int i = 0; list [i]; i++) {
-                char *quoted_opt = g_shell_quote (list [i]);
-                cmdline += quoted_opt;
-                cmdline += Char (' ');
-                g_free (quoted_opt);
+        String asp = convertNode <Element> (n)->getAttribute ("aspectRatio");
+        if (!asp.isNull ()) {
+            int p = asp.indexOf (Char (':'));
+            if (p > 0) {
+                int a = asp.left (p).toInt ();
+                int b = asp.mid (p + 1).toInt ();
+                if (a > 0 && b > 0)
+                    cmdline += String ("-aspect ") +
+                        String::number (a) + Char (':') + String::number (b);
+            } else {
+                float a = (float) asp.toDouble ();
+                if (a > 0.01) {
+                    char buf[32];
+                    snprintf (buf, sizeof (buf), "%0.3f", a);
+                    cmdline += String ("-aspect ") +
+                        String (buf).replace (Char (','), Char ('.'));
+                }
             }
-            g_strfreev (list);
+            cmdline += Char (' ');
             break;
         }
     }
@@ -1060,6 +1079,8 @@ KMPLAYER_NO_EXPORT bool OssoMediaServer::play (NodePtr node) {
     if (m_url.isEmpty ()) {
         return false;
     }
+    URL url (m_url);
+    is_local_file = url.isLocalFile ();
     have_played_stream = false;
     DBusConnection * connection = (DBusConnection *)osso_get_dbus_connection (m_osso_context);
     if (m_state < Buffering) {
@@ -1204,6 +1225,9 @@ KMPLAYER_NO_EXPORT void OssoMediaServer::processPlaying () {
     have_played_stream = true;
     if (!pos_timer)
         pos_timer = g_timeout_add (5000, cb_getPosition, this);
+    Mrl *m = mrl ();
+    if (is_local_file && m && m->clip_begin > 10)
+        seek (m->clip_begin, true);
 }
 
 KMPLAYER_NO_EXPORT void OssoMediaServer::processPaused () {
