@@ -76,6 +76,8 @@ public:// slots:
     KMPLAYER_NO_EXPORT const char * name () { return m_name; }
     void scheduledStateChanged ();
     ProcessNotify * processNotify () { return m_notify; }
+    int userStopPosition () const { return m_user_stop_position; }
+    void setUserStop ();
     void setState (State newstate);
     void setWidth (int w) { m_width = w; }
     void setHeight (int h) { m_height = h; }
@@ -84,6 +86,7 @@ public:// slots:
     void setHasVideo (bool b) { no_video = !b; }
     bool hasXv () const { return has_xv; }
     void setUseXv (bool b) { has_xv = b; }
+    bool isLocalFile () const { return is_local_file; }
 protected:
     //Source * m_source;
     //Settings * m_settings;
@@ -100,9 +103,11 @@ protected:
     int m_position;
     int m_width;
     int m_height;
+    int m_user_stop_position;
     float m_aspect;
     bool no_video;
     bool has_xv;
+    bool is_local_file;
     //int m_request_seek;
     //const char ** m_supported_sources;
 };
